HitchTest
=========

HitchTest is the main hitch plugin containing all of the core components
required to run a test.

It is installed into every .hitch virtualenv by the `bootstrapper <https://github.com/hitchtest/hitch>`_.

Documentation
-------------

* `Full hitch documentation <https://hitchtest.readthedocs.org/en/latest/>`_
* `hitchtest-specific API docs <https://hitchtest.readthedocs.org/en/latest/api/>`_
